Reverting commit d1123894d33922e7c8ca838f9dac9bdceefa3f7a as per Gilles request.

The work on revamping the random packages is perfoemd in the random-ravamp 
branch.


Project: http://git-wip-us.apache.org/repos/asf/commons-math/repo
Commit: http://git-wip-us.apache.org/repos/asf/commons-math/commit/81a6c887
Tree: http://git-wip-us.apache.org/repos/asf/commons-math/tree/81a6c887
Diff: http://git-wip-us.apache.org/repos/asf/commons-math/diff/81a6c887

Branch: refs/heads/master
Commit: 81a6c88778a6b84c14d07e087f20484f018ef320
Parents: 81288e4
Author: Luc Maisonobe <l...@apache.org>
Authored: Sun Jan 17 11:30:24 2016 +0100
Committer: Luc Maisonobe <l...@apache.org>
Committed: Sun Jan 17 11:40:27 2016 +0100

----------------------------------------------------------------------
 .../commons/math4/random/BaseRandomGenerator.java     | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/commons-math/blob/81a6c887/src/main/java/org/apache/commons/math4/random/BaseRandomGenerator.java
----------------------------------------------------------------------
diff --git 
a/src/main/java/org/apache/commons/math4/random/BaseRandomGenerator.java 
b/src/main/java/org/apache/commons/math4/random/BaseRandomGenerator.java
index bc6442e..da801b0 100644
--- a/src/main/java/org/apache/commons/math4/random/BaseRandomGenerator.java
+++ b/src/main/java/org/apache/commons/math4/random/BaseRandomGenerator.java
@@ -228,17 +228,17 @@ public abstract class BaseRandomGenerator
      * </p>
      *
      * @param bytes Array in which to put the generated bytes. Cannot be 
{@code null}.
      * @param start Index at which to start inserting the generated bytes.
      * @param len Number of bytes to insert.
      */
     private void nextBytesFill(byte[] bytes,
-                               int start,
-                               int len) {
-        int index = start; // Index of first insertion.
+                               int position,
+                               int length) {
+        int index = position; // Index of first insertion.
 
         // Index of first insertion plus multiple 4 part of length (i.e. length
         // with two least significant bits unset).
-        final int indexLoopLimit = index + (len & 0x7ffffffc);
+        final int indexLoopLimit = index + (length & 0x7ffffffc);
 
         // Start filling in the byte array, 4 bytes at a time.
         while (index < indexLoopLimit) {
@@ -249,7 +249,7 @@ public abstract class BaseRandomGenerator
             bytes[index++] = (byte) (random >>> 24);
         }
 
-        final int indexLimit = start + len; // Index of last insertion + 1.
+        final int indexLimit = position + length; // Index of last insertion + 
1.
 
         // Fill in the remaining bytes.
@@ -228,17 +228,17 @@ public abstract class BaseRandomGenerator
      * @param bytes Array in which to put the generated bytes. Cannot be 
{@code null}.
-     * @param start Index at which to start inserting the generated bytes.
-     * @param len Number of bytes to insert.
+     * @param position Index at which to start inserting the generated bytes.
+     * @param length Number of bytes to insert.
      */
     private void nextBytesFill(byte[] bytes,
         if (index < indexLimit) {

Reply via email to